package vps91

import (
	"net/url"
	"reflect"
	"vps91-go-sdk/com.vps91/common"
	"vps91-go-sdk/com.vps91/enums"
	"vps91-go-sdk/com.vps91/ext"
)


// DynamicGetIps 动态代理 -- 提取动态代理
func DynamicGetIps(dynamicgetips common.DynamicGetIps) string {
	t := reflect.TypeOf(dynamicgetips)
	v := reflect.ValueOf(dynamicgetips)
	params := make(map[string]string)
	appKey := dynamicgetips.Key()
	params = ext.StructToMap(t, v, params)
	var getipsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.DynamicGetIps)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getipsParams)
}

// DynamicCheck 动态代理 -- 校验IP可用性
func DynamicCheck(check common.DynamicCheck) string {
	t := reflect.TypeOf(check)
	v := reflect.ValueOf(check)
	params := make(map[string]string)
	appKey := check.Key()
	params = ext.StructToMap(t, v, params)
	var getipsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.DynamicCheck)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getipsParams)
}

// DynamicSetWhiteIp 动态代理 -- 设置代理IP白名单
func DynamicSetWhiteIp(ip common.DynamicSetWhiteIp) string {
	t := reflect.TypeOf(ip)
	v := reflect.ValueOf(ip)
	params := make(map[string]string)
	appKey := ip.Key()
	params = ext.StructToMap(t, v, params)
	var getipsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.DynamicSetWhiteIp)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getipsParams)
}

// DynamicReplaceWhiteIp 动态代理 -- 替换IP白名单
func DynamicReplaceWhiteIp(ip common.DynamicReplaceWhiteIp) string {
	t := reflect.TypeOf(ip)
	v := reflect.ValueOf(ip)
	params := make(map[string]string)
	appKey := ip.Key()
	params = ext.StructToMap(t, v, params)
	var getipsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.DynamicReplaceWhiteIp)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getipsParams)
}

// DynamicGetWhiteIp 动态代理 -- 获取IP白名单
func DynamicGetWhiteIp(ip common.DynamicGetWhiteIp) string {
	t := reflect.TypeOf(ip)
	v := reflect.ValueOf(ip)
	params := make(map[string]string)
	appKey := ip.Key()
	params = ext.StructToMap(t, v, params)
	var getipsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.DynamicGetWhiteIp)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getipsParams)
}

// DynamicRemain 动态代理 -- 获取代理剩余可用时长
func DynamicRemain(remain common.DynamicRemain) string {
	t := reflect.TypeOf(remain)
	v := reflect.ValueOf(remain)
	params := make(map[string]string)
	appKey := remain.Key()
	params = ext.StructToMap(t, v, params)
	var getipsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.DynamicRemain)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getipsParams)
}

// DynamicBalance 动态代理 -- 获取剩余可用时长
func DynamicBalance(balance common.DynamicBalance) string {
	t := reflect.TypeOf(balance)
	v := reflect.ValueOf(balance)
	params := make(map[string]string)
	appKey := balance.Key()
	params = ext.StructToMap(t, v, params)
	var getipsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.DynamicBalance)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getipsParams)
}

// AloneGetIps 独享代理 -- 获取代理详情
func AloneGetIps(ips common.AloneGetIps) string {
	t := reflect.TypeOf(ips)
	v := reflect.ValueOf(ips)
	params := make(map[string]string)
	appKey := ips.Key()
	params = ext.StructToMap(t, v, params)
	var getipsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.AloneGetIps)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getipsParams)
}

// AloneSetWhiteIp 独享代理 -- 设置代理IP白名单
func AloneSetWhiteIp(ip common.AloneSetWhiteIp) string {
	t := reflect.TypeOf(ip)
	v := reflect.ValueOf(ip)
	params := make(map[string]string)
	appKey := ip.Key()
	params = ext.StructToMap(t, v, params)
	var getipsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.AloneSetWhiteIp)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getipsParams)
}

// AloneReplaceWhiteIp 独享代理 -- 替换IP白名单
func AloneReplaceWhiteIp(ip common.AloneReplaceWhiteIp) string {
	t := reflect.TypeOf(ip)
	v := reflect.ValueOf(ip)
	params := make(map[string]string)
	appKey := ip.Key()
	params = ext.StructToMap(t, v, params)
	var getipsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.AloneReplaceWhiteIp)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getipsParams)
}

// AloneGetWhiteIp 独享代理 -- 获取代理IP白名单
func AloneGetWhiteIp(ip common.AloneGetWhiteIp) string {
	t := reflect.TypeOf(ip)
	v := reflect.ValueOf(ip)
	params := make(map[string]string)
	appKey := ip.Key()
	params = ext.StructToMap(t, v, params)
	var getipsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.AloneGetWhiteIp)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getipsParams)
}

// PostPayGetIps 按量付费 -- 获取代理详情
func PostPayGetIps(ips common.PostPayGetIps) string {
	t := reflect.TypeOf(ips)
	v := reflect.ValueOf(ips)
	params := make(map[string]string)
	appKey := ips.Key
	params = ext.StructTagToMap(t, v, params)
	var getIpsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.PostPayGetIps)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getIpsParams)
}

// PostPayCheckIps 按量付费 -- 检查ip的可用性
func PostPayCheckIps(ips common.PostPayCheckIps) string {
	t := reflect.TypeOf(ips)
	v := reflect.ValueOf(ips)
	params := make(map[string]string)
	appKey := ips.Key
	params = ext.StructTagToMap(t, v, params)
	var getIpsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.PostPayCheckIps)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getIpsParams)
}

// PostPaySetWhiteIp 按量付费 -- 设置代理IP白名单
func PostPaySetWhiteIp(ip common.PostPaySetWhiteIp) string {
	t := reflect.TypeOf(ip)
	v := reflect.ValueOf(ip)
	params := make(map[string]string)
	appKey := ip.Key
	params = ext.StructTagToMap(t, v, params)
	var getIpsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.PostPaySetWhiteIp)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getIpsParams)
}

// PostPayGetWhiteIp 按量付费 -- 获取代理IP白名单
func PostPayGetWhiteIp(ip common.PostPayGetWhiteIp) string {
	t := reflect.TypeOf(ip)
	v := reflect.ValueOf(ip)
	params := make(map[string]string)
	appKey := ip.Key
	params = ext.StructTagToMap(t, v, params)
	var getIpsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.PostPayGetWhiteIp)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getIpsParams)
}

// PostPayReplaceWhiteIp 按量付费 -- 替换IP白名单
func PostPayReplaceWhiteIp(ip common.PostPayReplaceWhiteIp) string {
	t := reflect.TypeOf(ip)
	v := reflect.ValueOf(ip)
	params := make(map[string]string)
	appKey := ip.Key
	params = ext.StructTagToMap(t, v, params)
	var getIpsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.PostPayReplaceWhiteIp)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getIpsParams)
}

// UnlimitedGetIps 不限量 -- 提取ip
func UnlimitedGetIps(ip common.UnlimitedGetIps) string {
	t := reflect.TypeOf(ip)
	v := reflect.ValueOf(ip)
	params := make(map[string]string)
	appKey := ip.Key
	params = ext.StructTagToMap(t, v, params)
	var getIpsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.UnlimitedGetIps)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getIpsParams)
}

// UnlimitedSetWhiteIp 不限量 -- 设置代理IP白名单
func UnlimitedSetWhiteIp(ip common.UnlimitedSetWhiteIp) string {
	t := reflect.TypeOf(ip)
	v := reflect.ValueOf(ip)
	params := make(map[string]string)
	appKey := ip.Key
	params = ext.StructTagToMap(t, v, params)
	var getIpsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.UnlimitedSetWhiteIp)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getIpsParams)
}

// UnlimitedGetWhiteIp 不限量 -- 获取代理IP白名单
func UnlimitedGetWhiteIp(ip common.UnlimitedGetWhiteIp) string {
	t := reflect.TypeOf(ip)
	v := reflect.ValueOf(ip)
	params := make(map[string]string)
	appKey := ip.Key
	params = ext.StructTagToMap(t, v, params)
	var getIpsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.UnlimitedGetWhiteIp)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getIpsParams)
}

// UnlimitedReplaceWhiteIp 不限量 -- 替换IP白名单
func UnlimitedReplaceWhiteIp(ip common.UnlimitedReplaceWhiteIp) string {
	t := reflect.TypeOf(ip)
	v := reflect.ValueOf(ip)
	params := make(map[string]string)
	appKey := ip.Key
	params = ext.StructTagToMap(t, v, params)
	var getIpsParams = ext.GetParams(params, appKey)
	Url, err := url.Parse(enums.UnlimitedReplaceWhiteIp)
	if err != nil {
		return ""
	}
	return ext.Post(Url, getIpsParams)
}
